@@ -171,7 +171,7 @@ impl AgentInternal {
         {
             let started_ch_tx = self.started_ch_tx.lock().await;
             if started_ch_tx.is_none() {
-                return Err(Error::ErrMultipleStart.into());
+                return Err(Error::ErrMultipleStart);
             }
         }
 
@@ -218,7 +218,9 @@ impl AgentInternal {
             }
 
             // We have been in checking longer then Disconnect+Failed timeout, set the connection to Failed
-            if Instant::now().duration_since(*checking_duration)
+            if Instant::now()
+                .checked_duration_since(*checking_duration)
+                .unwrap_or_else(|| Duration::from_secs(0))
                 > self.disconnected_timeout + self.failed_timeout
             {
                 self.update_connection_state(ConnectionState::Failed).await;
@@ -441,12 +443,9 @@ impl AgentInternal {
             (*selected_pair).as_ref().map_or_else(
                 || (false, Duration::from_secs(0)),
                 |selected_pair| {
-                    let disconnected_time = match SystemTime::now()
+                    let disconnected_time = SystemTime::now()
                         .duration_since(selected_pair.remote.last_received())
-                    {
-                        Ok(d) => d,
-                        Err(_) => Duration::from_secs(0),
-                    };
+                        .unwrap_or_else(|_| Duration::from_secs(0));
                     (true, disconnected_time)
                 },
             )
@@ -494,15 +493,13 @@ impl AgentInternal {
         };
 
         if let (Some(local), Some(remote)) = (local, remote) {
-            let last_sent = match SystemTime::now().duration_since(local.last_sent()) {
-                Ok(d) => d,
-                Err(_) => Duration::from_secs(0),
-            };
+            let last_sent = SystemTime::now()
+                .duration_since(local.last_sent())
+                .unwrap_or_else(|_| Duration::from_secs(0));
 
-            let last_received = match SystemTime::now().duration_since(remote.last_received()) {
-                Ok(d) => d,
-                Err(_) => Duration::from_secs(0),
-            };
+            let last_received = SystemTime::now()
+                .duration_since(remote.last_received())
+                .unwrap_or_else(|_| Duration::from_secs(0));
 
             if (self.keepalive_interval != Duration::from_secs(0))
                 && ((last_sent > self.keepalive_interval)
@@ -619,7 +616,7 @@ impl AgentInternal {
         let _d = {
             let mut done_tx = self.done_tx.lock().await;
             if done_tx.is_none() {
-                return Err(Error::ErrClosed.into());
+                return Err(Error::ErrClosed);
             }
             done_tx.take();
         };
@@ -785,7 +782,11 @@ impl AgentInternal {
 
         let mut temp = vec![];
         for binding_request in pending_binding_requests.drain(..) {
-            if filter_time.duration_since(binding_request.timestamp) < MAX_BINDING_REQUEST_TIMEOUT {
+            if filter_time
+                .checked_duration_since(binding_request.timestamp)
+                .map(|duration| duration < MAX_BINDING_REQUEST_TIMEOUT)
+                .unwrap_or(true)
+            {
                 temp.push(binding_request);
             }
         }
@@ -996,9 +997,9 @@ impl AgentInternal {
         remote_pwd: String,
     ) -> Result<()> {
         if remote_ufrag.is_empty() {
-            return Err(Error::ErrRemoteUfragEmpty.into());
+            return Err(Error::ErrRemoteUfragEmpty);
         } else if remote_pwd.is_empty() {
-            return Err(Error::ErrRemotePwdEmpty.into());
+            return Err(Error::ErrRemotePwdEmpty);
         }
 
         let mut ufrag_pwd = self.ufrag_pwd.lock().await;
@@ -1130,7 +1131,7 @@ impl AgentInternal {
         if let Some(mut initialized_ch) = initialized_ch {
             tokio::select! {
                 _ = initialized_ch.recv() => {}
-                _ = closed_ch_rx.recv() => return Err(Error::ErrClosed.into()),
+                _ = closed_ch_rx.recv() => return Err(Error::ErrClosed),
             }
         }
 
@@ -1145,10 +1146,10 @@ impl AgentInternal {
                             n = num;
                             src_addr = src;
                        }
-                       Err(err) => return Err(Error::new(err.to_string()).into()),
+                       Err(err) => return Err(Error::Other(err.to_string())),
                    }
                },
-                _  = closed_ch_rx.recv() => return Err(Error::ErrClosed.into()),
+                _  = closed_ch_rx.recv() => return Err(Error::ErrClosed),
             }
 
             self.handle_inbound_candidate_msg(&candidate, &buffer[..n], src_addr, addr)
